summaryrefslogtreecommitdiffstats
path: root/chalk/plugins/filters/cimg/CImg.h
diff options
context:
space:
mode:
Diffstat (limited to 'chalk/plugins/filters/cimg/CImg.h')
-rw-r--r--chalk/plugins/filters/cimg/CImg.h16
1 files changed, 8 insertions, 8 deletions
diff --git a/chalk/plugins/filters/cimg/CImg.h b/chalk/plugins/filters/cimg/CImg.h
index 871cb4969..f69fe2a1b 100644
--- a/chalk/plugins/filters/cimg/CImg.h
+++ b/chalk/plugins/filters/cimg/CImg.h
@@ -8799,8 +8799,8 @@ namespace cimg_library {
- -1 = Backward finite differences
- 0 = Centered finite differences
- 1 = Forward finite differences
- - 2 = Using Sobel tqmasks
- - 3 = Using rotation invariant tqmasks
+ - 2 = Using Sobel masks
+ - 3 = Using rotation invariant masks
- 4 = Using Deriche recusrsive filter.
**/
CImgl<typename cimg::largest<T,float>::type> get_gradientXY(const int scheme=0) const {
@@ -9822,7 +9822,7 @@ namespace cimg_library {
}
#endif
- //! Draw a tqmasked sprite image in the instance image, at coordinates (\c x0,\c y0,\c z0,\c v0).
+ //! Draw a masked sprite image in the instance image, at coordinates (\c x0,\c y0,\c z0,\c v0).
/**
\param sprite = sprite image.
\param tqmask = tqmask image.
@@ -9830,7 +9830,7 @@ namespace cimg_library {
\param y0 = Y-coordinate of the sprite position in the instance image.
\param z0 = Z-coordinate of the sprite position in the instance image.
\param v0 = V-coordinate of the sprite position in the instance image.
- \param tqmask_valmax = Maximum pixel value of the tqmask image \c tqmask.
+ \param mask_valmax = Maximum pixel value of the tqmask image \c tqmask.
\param opacity = opacity of the drawing.
\note Pixel values of \c tqmask set the opacity of the corresponding pixels in \c sprite.
\note Clipping is supported.
@@ -9838,7 +9838,7 @@ namespace cimg_library {
**/
template<typename ti,typename tm> CImg& draw_image(const CImg<ti>& sprite,const CImg<tm>& tqmask,
const int x0=0,const int y0=0,const int z0=0,const int v0=0,
- const tm tqmask_valmax=1,const float opacity=1) {
+ const tm mask_valmax=1,const float opacity=1) {
if (!is_empty()) {
if (sprite.is_empty())
throw CImgArgumentException("CImg<%s>::draw_image() : Specified sprite image (%u,%u,%u,%u,%p) is empty.",
@@ -9873,8 +9873,8 @@ namespace cimg_library {
for (int y=0; y<lY; y++) {
for (int x=0; x<lX; x++) {
const float mopacity = *(ptrm++)*opacity,
- nopacity = cimg::abs(mopacity), copacity = tqmask_valmax-cimg::max(mopacity,0.0f);
- *ptrd = (T)((nopacity*(*(ptrs++))+copacity*(*ptrd))/tqmask_valmax);
+ nopacity = cimg::abs(mopacity), copacity = mask_valmax-cimg::max(mopacity,0.0f);
+ *ptrd = (T)((nopacity*(*(ptrs++))+copacity*(*ptrd))/mask_valmax);
ptrd++;
}
ptrd+=offX; ptrs+=soffX; ptrm+=soffX;
@@ -12042,7 +12042,7 @@ namespace cimg_library {
}
}
} else {
// Generic version for other tqmasks
const int cxm=tqmask.width/2, cym=tqmask.height/2, czm=tqmask.depth/2, fxm=cxm-1+(tqmask.width%2), fym=cym-1+(tqmask.height%2), fzm=czm-1+(tqmask.depth%2);
cimg_mapV(*this,v)
if (!weighted_correl) { // Classical correlation
@@ -12042,7 +12042,7 @@ namespace cimg_library {
}
} else {
- // Generic version for other tqmasks
+ // Generic version for other masks
const int cxm=tqmask.width/2, cym=tqmask.height/2, czm=tqmask.depth/2, fxm=cxm-1+(tqmask.width%2), fym=cym-1+(tqmask.height%2), fzm=czm-1+(tqmask.depth%2);
cimg_mapV(*this,v)